profiler: modify integration test to pass with go1.11 (#4071)

diff --git a/profiler/integration_test.go b/profiler/integration_test.go
index eb906a6..53b9477 100644
--- a/profiler/integration_test.go
+++ b/profiler/integration_test.go
@@ -64,8 +64,9 @@
 mkdir -p /tmp/gocache
 export GOCACHE=/tmp/gocache
 
-# Install gcc, needed to install go master
-if [ "{{.GoVersion}}" = "master" ]
+# Install gcc, needed to install go master and cgo depencencies when using
+# go1.11.
+if [ "{{.GoVersion}}" = "master" ] || [[ "{{.GoVersion}}" =~ 1.11.* ]]
 then
 retry apt-get -y -q install gcc >/dev/null
 fi